@@ -1,5 +1,5 @@
 
-package Spreadsheet::Perl ;
+package Spreadsheet::Perl::Arithmetic ;
 
 use 5.006 ;
 
@@ -19,11 +19,13 @@ our %EXPORT_TAGS =
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } ) ;
 
-#~ our @EXPORT = qw( ) ;
-our @EXPORT ;
-push @EXPORT, qw( ) ;
+our @EXPORT = qw( ) ;
+#our @EXPORT ;
+#push @EXPORT, qw( ) ;
 
-our $VERSION = '0.01' ;
+our $VERSION = '0.02' ;
+
+use Spreadsheet::Perl ;
 
 #-------------------------------------------------------------------------------
 
@@ -53,6 +55,8 @@ for my $address (@addresses)
 return($sum) ;
 }
 
+DefineSpreadsheetFunction('Sum', \&Sum, undef, __PACKAGE__) ;
+
 #-------------------------------------------------------------------------------
 
 1 ;
